@@ -363,8 +363,8 @@ class square_grid:
                     pass
             if datax.crs ==None:
                 datax.crs ={'init': 'epsg:4326'}
-            final_hexa =gpd.overlay(data.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
-                                    gpd.overlay(data.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
+            final_hexa =gpd.overlay(datas.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
+                                    gpd.overlay(datas.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
                                                 datax, how='intersection'),
                                     how = 'union')[['geometry']].copy()
             area_thresholda = (length*length)*0.10
@@ -382,8 +382,8 @@ class square_grid:
                     pass
             if datax.crs ==None:
                 datax.crs ={'init': 'epsg:4326'}
-            final_hexa =gpd.overlay(data.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
-                                    gpd.overlay(data.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
+            final_hexa =gpd.overlay(datas.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
+                                    gpd.overlay(datas.explode().reset_index().drop(['level_0', 'level_1'], axis = 1),
                                                 datax, how='intersection'),
                                     how = 'union')[['geometry']].copy()
             area_thresholda = (length*length)*0.10
